==> cinder-9.0.0.0b1.tar.gz: cinder-9.0.0.0b1/cinder/tests/unit/fake_constants.py <==
#    Copyright 2016 Red Hat, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

ACTION_FAILED_ID = 'f26f181d-7891-4720-b022-b074ec1733ef'
ACTION2_FAILED_ID = '02f53bd8-3514-485b-ba60-2722ef09c016'
ALREADY_EXISTS_ID = '8f7495fe-5e44-4f33-81af-4b28e9b2952f'
ATTACHMENT_ID = '4dc3bb12-ad75-41b9-ab2c-7609e743e600'
ATTACHMENT2_ID = 'ac2439fe-c071-468f-94e3-547bedb95de0'
BACKUP_ID = '707844eb-6d8a-4ac1-8b98-618e1c0b3a3a'
BACKUP2_ID = '40e8462a-c9d8-462f-a810-b732a1790535'
BACKUP3_ID = '30ae7641-017e-4221-a642-855687c8bd71'
CGSNAPSHOT_ID = '5e34cce3-bc97-46b7-a127-5cfb95ef445d'
CGSNAPSHOT_NAME = 'cgsnapshot-5e34cce3-bc97-46b7-a127-5cfb95ef445d'
CGSNAPSHOT2_ID = '5c36d762-d6ba-4f04-bd07-88a298cc410a'
CGSNAPSHOT3_ID = '5f392156-fc03-492a-9cb8-e46a7eedaf33'
CONSISTENCY_GROUP_ID = 'f18abf73-79ee-4f2b-8d4f-1c044148f117'
CONSISTENCY_GROUP2_ID = '8afc8952-9dce-4228-9f8a-706c5cb5fc82'
ENCRYPTION_KEY_ID = 'e8387001-745d-45d0-9e4e-0473815ef09a'
IMAGE_ID = 'e79161cd-5f9d-4007-8823-81a807a64332'
INSTANCE_ID = 'fa617131-cdbc-45dc-afff-f21f17ae054e'
IN_USE_ID = '8ee42073-4ac2-4099-8c7a-d416630e6aee'
INVALID_ID = 'f45dcab0-ff2a-46ec-b3b7-74d6f4bb0027'
KEY_ID = '9112ecec-fb9d-4299-a948-ffb52650a5b5'
OBJECT_ID = 'd7c5b12f-d57d-4762-99ab-db5f62ae3569'
OBJECT2_ID = '51f5b8fa-c13c-48ba-8c9d-b470466cbc9c'
OBJECT3_ID = '7bf5ffa9-18a2-4b64-aab4-0798b53ee4e7'
PROJECT_ID = '89afd400-b646-4bbc-b12b-c0a4d63e5bd3'
PROJECT2_ID = '452ebfbc-55d9-402a-87af-65061916c24b'
PROJECT3_ID = 'f6c912d7-bf30-4b12-af81-a9e0b2f85f85'
PROVIDER_ID = '60087173-e899-470a-9e3a-ba4cffa3e3e3'
PROVIDER2_ID = '1060eccd-64bb-4ed2-86ce-aeaf135a97b8'
PROVIDER3_ID = '63736819-1c95-440e-a873-b9d685afede5'
PROVIDER4_ID = '7db06e02-26b6-4282-945d-7f6c9347a7b0'
QOS_SPEC_ID = 'fc0f7527-79d7-44be-a4f6-3b24db8e11ac'
QOS_SPEC2_ID = 'c561b69d-98d9-478c-815b-6de11f5a09c9'
QOS_SPEC3_ID = '6034720b-f586-4302-a1eb-fe30672069f6'
RAISE_ID = 'a56762e1-4a30-4008-b997-5a438ec9c457'
SNAPSHOT_ID = '253b2878-ec60-4793-ad19-e65496ec7aab'
SNAPSHOT_NAME = 'snapshot-253b2878-ec60-4793-ad19-e65496ec7aab'
SNAPSHOT2_ID = 'c02c44fa-5665-4a26-9e66-2ebaf25e5d2d'
SNAPSHOT3_ID = '454f9970-1e05-4193-a3ed-5c390c3faa18'
UPDATE_FAILED_ID = '110b29df-5e0f-4dbb-840c-ef5963d06933'
USER_ID = 'c853ca26-e8ea-4797-8a52-ee124a013d0e'
USER2_ID = '95f7b7ed-bd7f-426e-b05f-f1ffeb4f09df'
VOLUME_ID = '1e5177e7-95e5-4a0f-b170-e45f4b469f6a'
VOLUME_NAME = 'volume-1e5177e7-95e5-4a0f-b170-e45f4b469f6a'
VOLUME2_ID = '43a09914-e495-475f-b862-0bda3c8918e4'
VOLUME2_NAME = 'volume-43a09914-e495-475f-b862-0bda3c8918e4'
VOLUME3_ID = '1b1cf149-219c-44ac-aee3-13121a7f86a7'
VOLUME3_NAME = 'volume-1b1cf149-219c-44ac-aee3-13121a7f86a7'
VOLUME4_ID = '904d4602-4301-4e9b-8df1-8133b51904e6'
VOLUME4_NAME = 'volume-904d4602-4301-4e9b-8df1-8133b51904e6'
VOLUME5_ID = '17b0e01d-3d2d-4c31-a1aa-c962420bc3dc'
VOLUME5_NAME = 'volume-17b0e01d-3d2d-4c31-a1aa-c962420bc3dc'
VOLUME_NAME_ID = 'ee73d33c-52ed-4cb7-a8a9-2687c1205c22'
VOLUME2_NAME_ID = '63fbdd21-03bc-4309-b867-2893848f86af'
VOLUME_TYPE_ID = '4e9e6d23-eed0-426d-b90a-28f87a94b6fe'
VOLUME_TYPE2_ID = 'c4daaf47-c530-4901-b28e-f5f0a359c4e6'
VOLUME_TYPE3_ID = 'a3d55d15-eeb1-4816-ada9-bf82decc09b3'
VOLUME_TYPE4_ID = '69943076-754d-4da8-8718-0b0117e9cab1'
VOLUME_TYPE5_ID = '1c450d81-8aab-459e-b338-a6569139b835'
WILL_NOT_BE_FOUND_ID = 'ce816f65-c5aa-46d6-bd62-5272752d584a'

==> cinder_10.0.1.orig.tar.gz: cinder-10.0.1/cinder/tests/unit/fake_constants.py <==
#    Copyright 2016 Red Hat, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

ACTION_FAILED_ID = 'f26f181d-7891-4720-b022-b074ec1733ef'
ACTION2_FAILED_ID = '02f53bd8-3514-485b-ba60-2722ef09c016'
ALREADY_EXISTS_ID = '8f7495fe-5e44-4f33-81af-4b28e9b2952f'
ATTACHMENT_ID = '4dc3bb12-ad75-41b9-ab2c-7609e743e600'
ATTACHMENT2_ID = 'ac2439fe-c071-468f-94e3-547bedb95de0'
BACKUP_ID = '707844eb-6d8a-4ac1-8b98-618e1c0b3a3a'
BACKUP2_ID = '40e8462a-c9d8-462f-a810-b732a1790535'
BACKUP3_ID = '30ae7641-017e-4221-a642-855687c8bd71'
BACKUP4_ID = '23f8605b-8273-4f49-9b3d-1eeca81a63c2'
BACKUP5_ID = '50c97b22-51ea-440b-8d01-ded20a55d7e0'
CGSNAPSHOT_ID = '5e34cce3-bc97-46b7-a127-5cfb95ef445d'
CGSNAPSHOT_NAME = 'cgsnapshot-5e34cce3-bc97-46b7-a127-5cfb95ef445d'
CGSNAPSHOT2_ID = '5c36d762-d6ba-4f04-bd07-88a298cc410a'
CGSNAPSHOT3_ID = '5f392156-fc03-492a-9cb8-e46a7eedaf33'
CONSISTENCY_GROUP_ID = 'f18abf73-79ee-4f2b-8d4f-1c044148f117'
CONSISTENCY_GROUP2_ID = '8afc8952-9dce-4228-9f8a-706c5cb5fc82'
ENCRYPTION_KEY_ID = 'e8387001-745d-45d0-9e4e-0473815ef09a'
IMAGE_ID = 'e79161cd-5f9d-4007-8823-81a807a64332'
INSTANCE_ID = 'fa617131-cdbc-45dc-afff-f21f17ae054e'
IN_USE_ID = '8ee42073-4ac2-4099-8c7a-d416630e6aee'
INVALID_ID = 'f45dcab0-ff2a-46ec-b3b7-74d6f4bb0027'
KEY_ID = '9112ecec-fb9d-4299-a948-ffb52650a5b5'
OBJECT_ID = 'd7c5b12f-d57d-4762-99ab-db5f62ae3569'
OBJECT2_ID = '51f5b8fa-c13c-48ba-8c9d-b470466cbc9c'
OBJECT3_ID = '7bf5ffa9-18a2-4b64-aab4-0798b53ee4e7'
PROJECT_ID = '89afd400-b646-4bbc-b12b-c0a4d63e5bd3'
PROJECT2_ID = '452ebfbc-55d9-402a-87af-65061916c24b'
PROJECT3_ID = 'f6c912d7-bf30-4b12-af81-a9e0b2f85f85'
PROVIDER_ID = '60087173-e899-470a-9e3a-ba4cffa3e3e3'
PROVIDER2_ID = '1060eccd-64bb-4ed2-86ce-aeaf135a97b8'
PROVIDER3_ID = '63736819-1c95-440e-a873-b9d685afede5'
PROVIDER4_ID = '7db06e02-26b6-4282-945d-7f6c9347a7b0'
QOS_SPEC_ID = 'fc0f7527-79d7-44be-a4f6-3b24db8e11ac'
QOS_SPEC2_ID = 'c561b69d-98d9-478c-815b-6de11f5a09c9'
QOS_SPEC3_ID = '6034720b-f586-4302-a1eb-fe30672069f6'
RAISE_ID = 'a56762e1-4a30-4008-b997-5a438ec9c457'
SNAPSHOT_ID = '253b2878-ec60-4793-ad19-e65496ec7aab'
SNAPSHOT_NAME = 'snapshot-253b2878-ec60-4793-ad19-e65496ec7aab'
SNAPSHOT2_ID = 'c02c44fa-5665-4a26-9e66-2ebaf25e5d2d'
SNAPSHOT3_ID = '454f9970-1e05-4193-a3ed-5c390c3faa18'
UPDATE_FAILED_ID = '110b29df-5e0f-4dbb-840c-ef5963d06933'
USER_ID = 'c853ca26-e8ea-4797-8a52-ee124a013d0e'
USER2_ID = '95f7b7ed-bd7f-426e-b05f-f1ffeb4f09df'
VOLUME_ID = '1e5177e7-95e5-4a0f-b170-e45f4b469f6a'
VOLUME_NAME = 'volume-1e5177e7-95e5-4a0f-b170-e45f4b469f6a'
VOLUME2_ID = '43a09914-e495-475f-b862-0bda3c8918e4'
VOLUME2_NAME = 'volume-43a09914-e495-475f-b862-0bda3c8918e4'
VOLUME3_ID = '1b1cf149-219c-44ac-aee3-13121a7f86a7'
VOLUME3_NAME = 'volume-1b1cf149-219c-44ac-aee3-13121a7f86a7'
VOLUME4_ID = '904d4602-4301-4e9b-8df1-8133b51904e6'
VOLUME4_NAME = 'volume-904d4602-4301-4e9b-8df1-8133b51904e6'
VOLUME5_ID = '17b0e01d-3d2d-4c31-a1aa-c962420bc3dc'
VOLUME5_NAME = 'volume-17b0e01d-3d2d-4c31-a1aa-c962420bc3dc'
VOLUME_NAME_ID = 'ee73d33c-52ed-4cb7-a8a9-2687c1205c22'
VOLUME2_NAME_ID = '63fbdd21-03bc-4309-b867-2893848f86af'
VOLUME_TYPE_ID = '4e9e6d23-eed0-426d-b90a-28f87a94b6fe'
VOLUME_TYPE2_ID = 'c4daaf47-c530-4901-b28e-f5f0a359c4e6'
VOLUME_TYPE3_ID = 'a3d55d15-eeb1-4816-ada9-bf82decc09b3'
VOLUME_TYPE4_ID = '69943076-754d-4da8-8718-0b0117e9cab1'
VOLUME_TYPE5_ID = '1c450d81-8aab-459e-b338-a6569139b835'
WILL_NOT_BE_FOUND_ID = 'ce816f65-c5aa-46d6-bd62-5272752d584a'
GROUP_TYPE_ID = '29514915-5208-46ab-9ece-1cc4688ad0c1'
GROUP_TYPE2_ID = 'f8645498-1323-47a2-9442-5c57724d2e3c'
GROUP_TYPE3_ID = '1b7915f4-b899-4510-9eff-bd67508c3334'
GROUP_ID = '9a965cc6-ee3a-468d-a721-cebb193f696f'
GROUP2_ID = '40a85639-abc3-4461-9230-b131abd8ee07'
GROUP_SNAPSHOT_ID = '1e2ab152-44f0-11e6-819f-000c29d19d84'
GROUP_SNAPSHOT2_ID = '33e2ff04-44f0-11e6-819f-000c29d19d84'

# I don't care what it's used for, I just want a damn UUID
UUID1 = '84d0c5f7-2349-401c-8672-f76214d13cab'
UUID2 = '25406d50-e645-4e62-a9ef-1f53f9cba13f'
UUID3 = '29c80662-3a9f-4844-a585-55cd3cd180b5'
UUID4 = '4cd72b2b-5a4f-4f24-93dc-7c0212002916'
UUID5 = '0a574d83-cacf-42b9-8f9f-8f4faa6d4746'
